@@ -1,10 +1,8 @@
 package Data::Localize::Format::Maketext;
-use Any::Moose;
+use Moo;
 
 extends 'Data::Localize::Format';
 
-no Any::Moose;
-
 sub format {
     my ($self, $lang, $value, @args) = @_;
 
@@ -23,8 +21,6 @@ sub format {
     return $value;
 }
 
-__PACKAGE__->meta->make_immutable();
-
 1;
 
 __END__
