@@ -1,5 +1,5 @@
 package Data::Localize::Storage::Hash;
-use Any::Moose;
+use Moo;
 
 with 'Data::Localize::Storage';
 
@@ -13,10 +13,6 @@ sub set {
     $self->{$_[0]} = $_[1];
 }
 
-__PACKAGE__->meta->make_immutable();
-
-no Any::Moose;
-
 1;
 
 __END__
